@@ -26,6 +26,7 @@ import gi
 gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gio
 import warnings
 warnings.filterwarnings(
     "ignore", "Accessed deprecated property", DeprecationWarning)
@@ -33,11 +34,13 @@ warnings.filterwarnings(
 import logging
 import datetime
 import dbus
+import distro_info
 import os
 import subprocess
 
 import HweSupportStatus.consts
 from .Core.LivePatchSocket import LivePatchSocket
+from .Core.utils import get_dist
 
 from gettext import gettext as _
 from gettext import ngettext
@@ -97,6 +100,8 @@ class InternalDialog(BuilderDialog):
         ui_path = os.path.join(window_main.datadir, "gtkbuilder/Dialog.ui")
         BuilderDialog.__init__(self, window_main, ui_path, "pane_dialog")
 
+        self.settings = Gio.Settings.new("com.ubuntu.update-manager")
+
         self.focus_button = None
         self.set_content_widget(content_widget)
         self.connect("realize", self._on_realize)
@@ -144,10 +149,22 @@ class InternalDialog(BuilderDialog):
             self.main_container.add(content_widget)
         self.main_container.set_visible(bool(content_widget))
 
+    def _is_livepatch_supported(self):
+        di = distro_info.UbuntuDistroInfo()
+        codename = get_dist()
+        return di.is_lts(codename)
+
     def on_livepatch_status_ready(self, active, cs, ps, fixes):
         self.set_desc(None)
 
         if not active:
+            if self._is_livepatch_supported() and \
+               self.settings_button and \
+               self.settings.get_int('launch-count') >= 4:
+                self.set_desc(_("<b>Tip:</b> You can use Livepatch to "
+                                "keep your computer more secure between "
+                                "restarts."))
+                self.settings_button.set_label(_("Settings & Livepatch…"))
             return
 
         needs_reschedule = False
@@ -208,7 +225,7 @@ class NoUpdatesDialog(InternalDialog):
             self.set_header(_("No software updates are available."))
         else:
             self.set_header(_("The software on this computer is up to date."))
-        self.add_settings_button()
+        self.settings_button = self.add_settings_button()
         self.focus_button = self.add_button(Gtk.STOCK_OK,
                                             self.window_main.close)
         self.check_livepatch_status()
