@@ -26,6 +26,7 @@ from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
+from gi.repository import GObject
 
 GdkX11  # pyflakes
 
@@ -94,7 +95,9 @@ class UpdateManager(Gtk.Window):
 
         # Keep window at a constant size
         ctx = self.get_style_context()
-        ctx.connect("changed", lambda ctx: self.resize_to_standard_width())
+        self.style_changed = ctx.connect("changed",
+                                         lambda ctx:
+                                             self.resize_to_standard_width())
 
         # Signals
         self.connect("delete-event", self._on_close)
@@ -135,9 +138,11 @@ class UpdateManager(Gtk.Window):
         if dpi <= 0:
             dpi = 96
         ctx = self.get_style_context()
+        GObject.signal_handler_block(ctx, self.style_changed)
         size = ctx.get_property("font-size", Gtk.StateFlags.NORMAL)
         width = dpi / 72 * size * num_em
         self.set_size_request(width, -1)
+        GObject.signal_handler_unblock(ctx, self.style_changed)
 
     def on_initial_focus_in(self, widget, event):
         """callback run on initial focus-in (if started unmapped)"""
@@ -267,8 +272,8 @@ class UpdateManager(Gtk.Window):
                 return HWEUpgradeDialog(self)
             return UpdatesAvailable(self, header, desc, need_reboot)
 
-    def start_error(self, is_update_error, header, desc):
-        if is_update_error:
+    def start_error(self, update_and_retry, header, desc):
+        if update_and_retry:
             self._start_pane(UpdateErrorDialog(self, header, desc))
         else:
             self._start_pane(ErrorDialog(self, header, desc))
